# coding: utf-8
"""
Python module DocString
"""
__author__ = 'fattakhov'
from django.test import TestCase

from kinder.core.unit.models import Unit

from gisdo import constants as const
from gisdo.alchemy_session import session_scope
from gisdo.index import ApplicationIndex, EnrolledIndex


class GISDOTestCase(TestCase):
    """
    Тесты приложения взаимодействия с ГИСДО
    """

    def test_soap_request_generation(self):
        self.assertEquals(2+2, 4, 'Generated XML data is not a dict.')


class ApplicationIndexTest(TestCase):
    """
    Тесты для группы показателей "Общее количество поданных заявлений"
    """

    def test_sum_age_slice_equal_sum_delivery_slice(self):
        """
        Проверяем, чтобы сумма количества заявлений в разрезе возрастных
        категорий была равно сумме количества заявлений в разрезе типа подачи
        """

        units = Unit.objects.filter(kind__id=4)

        with session_scope() as session:
            for dou in units:
                index = ApplicationIndex(dou, session)
                sum_in_age_slice = 0
                for age in const.AGE_CATEGORIES_FULL.values():
                    sum_in_age_slice += index.get_count(age_range=age)
                sum_in_delivery_slice = 0
                sum_in_delivery_slice += (index.get_count(index_type=ApplicationIndex.COUNT_BY_DELIVERY, age_range=age))
                sum_in_delivery_slice += (index.get_count(index_type=ApplicationIndex.COUNT_BY_DELIVERY, portal=1,
                                                          age_range=age))
                self.assertEquals(sum_in_age_slice, sum_in_delivery_slice, u'Ошибка по организации %s' % dou.name)


class EnrolledIndexTest(TestCase):
    """
    Тесты для группы показателей "Общее количество поданных заявлений"
    """

    def test_sum_disabled_group_equals_sum_correct_and_health_groups(self):
        """
        Сумма показателей "Количества детей в группах для детей с
        ограниченными возможностями" в разрезе возрастных
        категорий должно равняться сумме "Количества детей в оздоровительных группах" и
        "Количество детей в компенсирующих группах
        """

        units = Unit.objects.filter(kind__id=4)

        with session_scope() as session:
            for dou in units:
                index = EnrolledIndex(dou, session)
                sum_in_disabled_group_age_slice = 0
                for age in const.AGE_CATEGORIES_FULL.values():
                    sum_in_disabled_group_age_slice += index.get_count(age_range=age,
                                                                       index_type=EnrolledIndex.COUNT_DISABLED)
                sum_in_correct_and_health_groups = 0
                sum_in_correct_and_health_groups += index.get_count(index_type=EnrolledIndex.COUNT_CORRECT)
                sum_in_correct_and_health_groups += index.get_count(index_type=EnrolledIndex.COUNT_HEALTH)

                self.assertEqual(sum_in_disabled_group_age_slice, sum_in_correct_and_health_groups,
                                 u'Ошибка по организации %s' % dou.name)